# -*- coding: utf-8 -*-
"""
List of Galician comarcas (as of January 2013) to use as select choices.

Sorted alphabetically, with initial articles at the end.

Also included is a dictionary mapping each comarca code
to the list of municipality codes it contains.
"""

from __future__ import unicode_literals
from django.utils.translation import ugettext_lazy as _


# The choice tuple value represents the geographical code for each comarca,
# as per the comarca listing by Francisco Ruiz at
# http://alarcos.esi.uclm.es/per/fruiz/pobesp/ter_com.htm

COMARCA_CHOICES = (
    ('1232', _('Allariz-Maceda')),
    ('1219', _('Ancares, Os')),
    ('1201', _('Arzúa')),
    ('1233', _('Baixa Limia, A')),
    ('1244', _('Baixo Miño, O')),
    ('1202', _('Barbanza')),
    ('1203', _('Barcala, A')),
    ('1204', _('Bergantiños')),
    ('1205', _('Betanzos')),
    ('1245', _('Caldas')),
    ('1235', _('Carballiño, O')),
    ('1220', _('Chantada')),
    ('1246', _('Condado, O')),
    ('1206', _('Coruña, A')),
    ('1247', _('Deza')),
    ('1207', _('Eume')),
    ('1208', _('Ferrol')),
    ('1209', _('Fisterra')),
    ('1221', _('Fonsagrada, A')),
    ('1234', _('Limia, A')),
    ('1222', _('Lugo')),
    ('1223', _('Mariña Central, A')),
    ('1224', _('Mariña Occidental, A')),
    ('1225', _('Mariña Oriental, A')),
    ('1226', _('Meira')),
    ('1248', _('Morrazo, O')),
    ('1210', _('Muros')),
    ('1211', _('Noia')),
    ('1212', _('Ordes')),
    ('1213', _('Ortegal')),
    ('1236', _('Ourense')),
    ('1249', _('Paradanta, A')),
    ('1250', _('Pontevedra')),
    ('1227', _('Quiroga')),
    ('1237', _('Ribeiro, O')),
    ('1251', _('Salnés, O')),
    ('1214', _('Santiago')),
    ('1215', _('Sar, O')),
    ('1228', _('Sarria')),
    ('1252', _('Tabeirós-Terra de Montes')),
    ('1229', _('Terra Chá')),
    ('1238', _('Terra de Caldelas')),
    ('1239', _('Terra de Celanova')),
    ('1230', _('Terra de Lemos')),
    ('1216', _('Terra de Melide')),
    ('1217', _('Terra de Soneira')),
    ('1240', _('Terra de Trives')),
    ('1231', _('Ulloa, A')),
    ('1241', _('Valdeorras')),
    ('1242', _('Verín')),
    ('1243', _('Viana')),
    ('1253', _('Vigo')),
    ('1218', _('Xallas')),
)


# Please note that each municipality code list below
# is sorted according to their order in
# es_ga_municipalities.MUNICIPALITY_CHOICES,
# i.e., by the denomination with initial article at the
# end, separated by a comma

COMARCAS_WITH_MUNICIPALITIES = {
    '1201': [
        '15006',
        '15010',
        '15066',
        '15085',
    ],
    '1202': [
        '15011',
        '15067',
        '15072',
        '15073',
    ],
    '1203': [
        '15007',
        '15056',
    ],
    '1204': [
        '15014',
        '15019',
        '15029',
        '15041',
        '15040',
        '15043',
        '15068',
    ],
    '1205': [
        '15003',
        '15009',
        '15026',
        '15027',
        '15032',
        '15039',
        '15048',
        '15063',
        '15064',
        '15091',
        '15090',
    ],
    '1206': [
        '15001',
        '15005',
        '15008',
        '15017',
        '15021',
        '15030',
        '15031',
        '15058',
        '15075',
    ],
    '1207': [
        '15015',
        '15018',
        '15050',
        '15069',
        '15070',
    ],
    '1208': [
        '15004',
        '15022',
        '15035',
        '15036',
        '15049',
        '15051',
        '15054',
        '15055',
        '15076',
        '15081',
        '15087',
    ],
    '1209': [
        '15023',
        '15028',
        '15034',
        '15037',
        '15052',
    ],
    '1210': [
        '15020',
        '15053',
    ],
    '1211': [
        '15042',
        '15057',
        '15062',
        '15071',
    ],
    '1212': [
        '15024',
        '15038',
        '15047',
        '15059',
        '15060',
        '15084',
        '15086',
    ],
    '1213': [
        '15901',
        '15025',
        '15044',
        '15061',
    ],
    '1214': [
        '15002',
        '15012',
        '15013',
        '15078',
        '15082',
        '15088',
        '15089',
    ],
    '1215': [
        '15033',
        '15065',
        '15074',
    ],
    '1216': [
        '15046',
        '15079',
        '15080',
        '15083',
    ],
    '1217': [
        '15016',
        '15092',
        '15093',
    ],
    '1218': [
        '15045',
        '15077',
    ],
    '1219': [
        '27901',
        '27006',
        '27012',
        '27034',
        '27037',
        '27045',
    ],
    '1220': [
        '27009',
        '27016',
        '27060',
    ],
    '1221': [
        '27004',
        '27018',
        '27035',
    ],
    '1222': [
        '27011',
        '27014',
        '27020',
        '27023',
        '27028',
        '27039',
        '27049',
        '27056',
    ],
    '1223': [
        '27002',
        '27902',
        '27019',
        '27027',
        '27030',
        '27063',
    ],
    '1224': [
        '27013',
        '27038',
        '27064',
        '27066',
        '27025',
    ],
    '1225': [
        '27005',
        '27048',
        '27051',
        '27061',
    ],
    '1226': [
        '27029',
        '27046',
        '27053',
        '27054',
    ],
    '1227': [
        '27017',
        '27050',
        '27052',
    ],
    '1228': [
        '27024',
        '27026',
        '27042',
        '27043',
        '27055',
        '27057',
        '27062',
    ],
    '1229': [
        '27001',
        '27007',
        '27010',
        '27015',
        '27022',
        '27033',
        '27044',
        '27065',
        '27021',
    ],
    '1230': [
        '27008',
        '27031',
        '27041',
        '27047',
        '27058',
        '27059',
    ],
    '1231': [
        '27003',
        '27032',
        '27040',
    ],
    '1232': [
        '32001',
        '32007',
        '32043',
        '32055',
        '32036',
        '32037',
    ],
    '1233': [
        '32006',
        '32030',
        '32041',
        '32042',
        '32051',
    ],
    '1234': [
        '32005',
        '32012',
        '32016',
        '32062',
        '32067',
        '32077',
        '32078',
        '32082',
        '32089',
        '32090',
        '32032',
    ],
    '1235': [
        '32011',
        '32013',
        '32019',
        '32035',
        '32045',
        '32061',
        '32065',
        '32074',
        '32076',
    ],
    '1236': [
        '32002',
        '32008',
        '32026',
        '32031',
        '32052',
        '32054',
        '32058',
        '32059',
        '32075',
        '32079',
        '32081',
        '32087',
    ],
    '1237': [
        '32003',
        '32004',
        '32010',
        '32018',
        '32022',
        '32025',
        '32027',
        '32040',
        '32046',
        '32069',
    ],
    '1238': [
        '32023',
        '32049',
        '32057',
        '32080',
    ],
    '1239': [
        '32014',
        '32020',
        '32024',
        '32033',
        '32047',
        '32056',
        '32064',
        '32066',
        '32068',
        '32084',
    ],
    '1240': [
        '32029',
        '32044',
        '32063',
        '32070',
    ],
    '1241': [
        '32009',
        '32015',
        '32017',
        '32038',
        '32060',
        '32073',
        '32072',
        '32083',
        '32088',
    ],
    '1242': [
        '32021',
        '32028',
        '32039',
        '32050',
        '32053',
        '32071',
        '32085',
        '32091',
    ],
    '1243': [
        '32034',
        '32048',
        '32086',
        '32092',
    ],
    '1244': [
        '36023',
        '36036',
        '36048',
        '36054',
        '36055',
    ],
    '1245': [
        '36005',
        '36010',
        '36015',
        '36032',
        '36044',
        '36040',
        '36056',
    ],
    '1246': [
        '36030',
        '36031',
        '36034',
        '36042',
        '36050',
    ],
    '1247': [
        '36020',
        '36016',
        '36024',
        '36047',
        '36052',
        '36059',
    ],
    '1248': [
        '36004',
        '36008',
        '36026',
        '36029',
    ],
    '1249': [
        '36001',
        '36009',
        '36013',
        '36014',
    ],
    '1250': [
        '36002',
        '36007',
        '36012',
        '36025',
        '36041',
        '36043',
        '36038',
        '36058',
    ],
    '1251': [
        '36006',
        '36022',
        '36901',
        '36027',
        '36028',
        '36046',
        '36051',
        '36060',
        '36061',
    ],
    '1252': [
        '36011',
        '36017',
        '36018',
    ],
    '1253': [
        '36003',
        '36019',
        '36021',
        '36033',
        '36035',
        '36037',
        '36039',
        '36045',
        '36049',
        '36053',
        '36057',
    ],
}
